@@ -1,7 +1,7 @@
 #' Retrieving a BigML Dataset
-#' @export 
-#' @templateVar family_name dataset
-#' @template family
+#' @export
+#' @family dataset methods
+#' @references \url{https://bigml.com/developers/datasets}
 #' @param source_id A string giving the name of the source id.
 #' @param include_overview A logical value indicating whether to provide a
 #'	simple data frame overview of fields.
@@ -10,8 +10,9 @@
 #' @template dataset_return
 #' @template normal_methods
 getDataset <-
-function (source_id, include_overview = TRUE, ...) 
+function (source_id, include_overview = TRUE, ...)
 {
+    message("Retrieving the dataset...")
     response = .basic_api(.DATASET_URL)$get(id = source_id)
     if (include_overview) {
         tmpfields = ldply(response$fields, function(y) {
